@@ -3,7 +3,7 @@
 # Test that if a device is missing for a mounted filesystem, btrfs fi show will
 # show which device exactly is missing.
 
-source "$TEST_TOP/common"
+source "$TEST_TOP/common" || exit
 
 check_prereq mkfs.btrfs
 check_prereq btrfs
@@ -20,6 +20,7 @@ run_check $SUDO_HELPER "$TOP/mkfs.btrfs" -f -d raid1 "${loopdevs[@]}"
 # Move the device, changing its path, simulating the device being missing
 run_check $SUDO_HELPER mv "$dev2" /dev/loop-non-existent
 
+cond_wait_for_loopdevs
 run_check $SUDO_HELPER mount -o degraded $dev1 $TEST_MNT
 
 if ! run_check_stdout $SUDO_HELPER "$TOP/btrfs" filesystem show "$TEST_MNT" | \
